package fr.itsee.season;

import android.app.Activity;
import android.content.Intent;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.DefaultItemAnimator;
import android.support.v7.widget.DividerItemDecoration;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.widget.SearchView;
import android.widget.Toast;

import java.util.ArrayList;
import java.util.List;

public class RechercheActivity extends AppCompatActivity {

    private RecyclerView recyclerView;
    private ProduitAdapterRecherche mAdapter;
    private List<Produit> resultatRecherche;
    private SearchView searchBar;
    private String recherche;



    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_recherche);

        searchBar = findViewById(R.id.bar_de_recherche);
        recyclerView = (RecyclerView) findViewById(R.id.recycler_view);
        mAdapter = new ProduitAdapterRecherche( new ArrayList<Produit>(), this.getApplicationContext());

        RecyclerView.LayoutManager mLayoutManager = new LinearLayoutManager(getApplicationContext());
        recyclerView.setLayoutManager(mLayoutManager);
        recyclerView.setItemAnimator(new DefaultItemAnimator());
        recyclerView.addItemDecoration(new DividerItemDecoration(this, LinearLayoutManager.VERTICAL));
        recyclerView.setAdapter(mAdapter);

        Intent intent = getIntent();
        recherche = intent.getStringExtra("recherche");


        mAdapter.setListeAllProduit(faireRecherche(recherche));


        mAdapter.setOnItemClickListener(new ProduitAdapterRecherche.OnItemClickListener() {
            @Override
            public void onClik(int position) {
                Intent intent = new Intent(RechercheActivity.this, FicheProduitActivity.class);
                intent.putExtra("produit", getProduit(position));
                startActivityForResult(intent, 5);

            }
        });
        recyclerView.setAdapter(mAdapter);

        searchBar.setOnQueryTextListener(new SearchView.OnQueryTextListener() {
            @Override
            public boolean onQueryTextSubmit(String s) {
                searchBar.clearFocus();
                mAdapter.setListeAllProduit(faireRecherche(s));
                mAdapter.notifyDataSetChanged();
                return false;
            }

            @Override
            public boolean onQueryTextChange(String s) {
                mAdapter.setListeAllProduit(faireRecherche(s));
                mAdapter.notifyDataSetChanged();
                return false;
            }
        });
        searchBar.clearFocus();

    }

    public List<Produit> faireRecherche(String valeur){
        resultatRecherche = new ArrayList<>();
        if (!CommandesActivity.listeAllProduits.isEmpty()) {
            for (Produit p : CommandesActivity.listeAllProduits) {
                if (p.getCode128().toLowerCase().contains(valeur.toLowerCase())) {
                    resultatRecherche.add(p);
                }
            }
            if (resultatRecherche.size() == 0) {
                Toast.makeText(getApplicationContext(), "Aucun résultat", Toast.LENGTH_SHORT).show();
                resultatRecherche = CommandesActivity.listeAllProduits;
            }
        }
        return resultatRecherche;
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == 5) {
            if(resultCode == Activity.RESULT_OK){
                Produit p = data.getParcelableExtra("produit");

                Intent returnIntent = new Intent();
                returnIntent.putExtra("produit", p);
                setResult(Activity.RESULT_OK,returnIntent);
                finish();
            }else if (resultCode == Activity.RESULT_CANCELED) {

            }
        }
    }

    public Produit getProduit(int position){
        return resultatRecherche.get(position);
    }
}
